Neighborhood

Enum Neighborhood 

pub enum Neighborhood {
    Orthogonal,
    Diagonal,
    Square,
}
Neighborhoods around a point. They do not contain the point itself

Variants



Orthogonal

The neighborhood consisting of the points directly North, South, East, and West of a point.



Diagonal

The neighborhood consisting of the points directly diagonal to a point.



Square

The neighborhood consisting of the square directly around the point.